DocumentChange

Struct DocumentChange 

pub struct DocumentChange {
    pub range: TextRange,
    pub new_text: String,
    pub old_text: String,
}
A single text edit: replace range in the source with new_text.

old_text records the bytes that were replaced so the change can be inverted (undone).

Fields

range: TextRange

The byte range that is replaced.

new_text: String

The text that replaces range.

old_text: String

The original text at range (used for undo).

Implementations

Source

impl DocumentChange

pub fn new( range: TextRange, new_text: impl Into<String>, old_text: impl Into<String>, ) -> Self

Creates a new DocumentChange.

pub fn apply(&self, source: &str) -> String

Applies this change to source, returning the modified string.

Panics if range refers to a byte offset outside of source or does not sit on a character boundary.

pub fn inverse(&self) -> Self

Returns the inverse of this change (suitable for undoing).

The inverse replaces the region [start .. start + new_text.len()] (i.e. the bytes written by apply) back with old_text.