DocumentHistory

Struct DocumentHistory 

pub struct DocumentHistory { /* private fields */ }
Undo/redo history for a document.

Changes are pushed as they are applied. undo returns the inverse of the most-recent change; redo re-applies a change that was undone.

Implementations

Source

impl DocumentHistory

pub fn new() -> Self

Creates an empty history.

pub fn push(&mut self, change: DocumentChange)

Records a new change. Any future (redo) stack is cleared.

pub fn undo(&mut self) -> Option<&DocumentChange>

Removes the most-recent change from the undo stack and returns a reference to it, or None if the stack is empty.

The inverse of the returned change is placed on the redo stack.

pub fn redo(&mut self) -> Option<&DocumentChange>

Re-applies the most-recently-undone change and returns a reference to it, or None if the redo stack is empty.

pub fn can_undo(&self) -> bool

Returns true if there is at least one change to undo.

pub fn can_redo(&self) -> bool

Returns true if there is at least one change to redo.