Workspace

Struct Workspace 

pub struct Workspace {
    pub root: Option<PathBuf>,
    /* private fields */
}
The editor workspace — open documents and their IDs.

Fields

root: Option<PathBuf>

Root directory for the workspace (e.g. the repo root).

Implementations

Source

impl Workspace

pub fn new() -> Self

Creates an empty workspace.

pub fn open(&mut self, doc: Document) -> DocumentId

Opens a document and returns its ID.

pub fn get(&self, id: &DocumentId) -> Option<&Document>

Returns a reference to a document by ID.

pub fn get_mut(&mut self, id: &DocumentId) -> Option<&mut Document>

Returns a mutable reference to a document by ID.

pub fn close(&mut self, id: &DocumentId) -> Option<Document>

Closes a document, returning it if it was open.

pub fn len(&self) -> usize

Returns the number of open documents.

pub fn is_empty(&self) -> bool

Returns true if no documents are open.