pub struct DocumentHistory { /* private fields */ }Expand description
Implementations
Sourceimpl DocumentHistory
impl DocumentHistory
Sourcepub fn push(&mut self, change: DocumentChange)
pub fn push(&mut self, change: DocumentChange)
Records a new change. Any future (redo) stack is cleared.
Sourcepub fn undo(&mut self) -> Option<&DocumentChange>
pub fn undo(&mut self) -> Option<&DocumentChange>
Removes the most-recent change from the undo stack and returns a
reference to it, or None if the stack is empty.
The inverse of the returned change is placed on the redo stack.
Sourcepub fn redo(&mut self) -> Option<&DocumentChange>
pub fn redo(&mut self) -> Option<&DocumentChange>
Re-applies the most-recently-undone change and returns a reference
to it, or None if the redo stack is empty.